# Changes

Version 0.4.2 (released 2024-05-22)

- Fix `mesh deltas` command due to missing prefix

Version 0.4.1 (released 2024-04-08)

- Exclude -781 terms from file generation too

Version 0.4.0 (released 2024-04-05)

- Support update of LCSH terms under new architecture

Version 0.3.5 (released 2024-03-21)

- Rearchitecture to support updating subjects in a live instance.

Version 0.2.0 (released 2023-11-06)

- Support LCSH terms.

Version 0.1.0 (released 2023-10-30)

- Initial public release.
